@@ -7,6 +7,7 @@ class Crawler:
     def __init__(self, root) -> None:
         self.root = root
         self.fetcher = Fetcher()
+        self.visitedSites = set()
 
 
     def crawl(self):
@@ -28,10 +29,17 @@ class Crawler:
         list_href = scraper.gethref()
         if list_href.count == 0 or not list_href: return None
         list_href.map(lambda x: x.url())
-        list_href.forEach(lambda x: Terminal.found(x))
+        list_href.filter(self.visitedSites)
         responses = self.fetcher.get_all_pages(list_href.contents)
         responses.removeErrors()
         return responses
+
+    def visited(self, url):
+        if url in self.visitedSites: return False
+        else:
+            Terminal.found(url)
+            self.visitedSites.add(url)
+            return True
     
     def isError(self, response): return isinstance(response, RequestError)
 
